@@ -1,4 +1,4 @@
-﻿define(['browser', 'paper-fab', 'paper-tabs', 'paper-slider', 'paper-icon-button'], function (browser) {
+﻿define(['browser', 'datetime', 'libraryBrowser', 'listView', 'userdataButtons', 'cardStyle'], function (browser, datetime, libraryBrowser, listView, userdataButtons) {
 
     function showSlideshowMenu(context) {
         require(['scripts/slideshow'], function () {
@@ -32,12 +32,12 @@
             }
 
             var menuItem = {
-                name: name,
+                name: s.DisplayTitle || name,
                 id: s.Index
             };
 
             if (s.Index == currentIndex) {
-                menuItem.ironIcon = 'check';
+                menuItem.selected = true;
             }
 
             return menuItem;
@@ -83,12 +83,12 @@
             }
 
             var menuItem = {
-                name: name,
+                name: s.DisplayTitle || name,
                 id: s.Index
             };
 
             if (s.Index == currentIndex) {
-                menuItem.ironIcon = 'check';
+                menuItem.selected = true;
             }
 
             return menuItem;
@@ -97,7 +97,7 @@
         menuItems.unshift({
             id: -1,
             name: Globalize.translate('ButtonOff'),
-            ironIcon: currentIndex == null ? 'check' : null
+            selected: currentIndex == null
         });
 
         require(['actionsheet'], function (actionsheet) {
@@ -196,11 +196,17 @@
             // But for now, if you change songs but keep the same artist, the backdrop will flicker because in-between songs it clears out the image
             if (!browser.mobile) {
                 // Exclude from mobile because it just doesn't perform well
-                Backdrops.setBackdropUrl(context, backdropUrl);
+                require(['backdrop'], function (backdrop) {
+                    backdrop.setBackdrop(backdropUrl);
+                });
             }
 
             ApiClient.getItem(Dashboard.getCurrentUserId(), item.Id).then(function (fullItem) {
-                context.querySelector('.nowPlayingPageUserDataButtons').innerHTML = LibraryBrowser.getUserDataIconsHtml(fullItem, false);
+                context.querySelector('.nowPlayingPageUserDataButtons').innerHTML = userdataButtons.getIconsHtml({
+                    item: fullItem,
+                    includePlayed: false,
+                    style: 'fab-mini'
+                });
             });
         } else {
             context.querySelector('.nowPlayingPageUserDataButtons').innerHTML = '';
@@ -232,8 +238,6 @@
 
     function hideChapterMenu(page) {
 
-        //$('.chapterMenuOverlay', page).hide();
-        //$('.chapterMenu', page).hide();
     }
 
     return function () {
@@ -341,11 +345,11 @@
             if (playState.PositionTicks == null) {
                 context.querySelector('.positionTime').innerHTML = '--:--';
             } else {
-                context.querySelector('.positionTime').innerHTML = Dashboard.getDisplayTime(playState.PositionTicks);
+                context.querySelector('.positionTime').innerHTML = datetime.getDisplayRunningTime(playState.PositionTicks);
             }
 
             if (item && item.RunTimeTicks != null) {
-                context.querySelector('.runtime').innerHTML = Dashboard.getDisplayTime(item.RunTimeTicks);
+                context.querySelector('.runtime').innerHTML = datetime.getDisplayRunningTime(item.RunTimeTicks);
             } else {
                 context.querySelector('.runtime').innerHTML = '--:--';
             }
@@ -371,14 +375,14 @@
             var toggleRepeatButton = context.querySelector('.repeatToggleButton');
 
             if (playState.RepeatMode == 'RepeatAll') {
-                toggleRepeatButton.icon = "repeat";
+                toggleRepeatButton.innerHTML = "<i class='md-icon'>repeat</i>";
                 toggleRepeatButton.classList.add('nowPlayingPageRepeatActive');
             }
             else if (playState.RepeatMode == 'RepeatOne') {
-                toggleRepeatButton.icon = "repeat-one";
+                toggleRepeatButton.innerHTML = "<i class='md-icon'>repeat_one</i>";
                 toggleRepeatButton.classList.add('nowPlayingPageRepeatActive');
             } else {
-                toggleRepeatButton.icon = "repeat";
+                toggleRepeatButton.innerHTML = "<i class='md-icon'>repeat</i>";
                 toggleRepeatButton.classList.remove('nowPlayingPageRepeatActive');
             }
 
@@ -395,7 +399,7 @@
             //    SortOrder: "Ascending",
             //    IncludeItemTypes: "Audio",
             //    Recursive: true,
-            //    Fields: "PrimaryImageAspectRatio,SortName,MediaSourceCount,SyncInfo",
+            //    Fields: "PrimaryImageAspectRatio,SortName,MediaSourceCount",
             //    StartIndex: 0,
             //    ImageTypeLimit: 1,
             //    EnableImageTypes: "Primary,Backdrop,Banner,Thumb",
@@ -403,52 +407,40 @@
 
             //}).then(function (result) {
 
-            //    html += LibraryBrowser.getListViewHtml({
+            //    html += listView.getListViewHtml({
             //        items: result.Items,
             //        smallIcon: true
             //    });
 
-            //    $(".playlist", page).html(html).lazyChildren();
+            //    page(".playlist").html(html).lazyChildren();
             //});
 
-            var playlistOpen = isPlaylistOpen(context);
+            html += listView.getListViewHtml({
+                items: MediaController.playlist(),
+                smallIcon: true,
+                action: 'setplaylistindex'
+            });
 
-            if (playlistOpen) {
-
-                html += LibraryBrowser.getListViewHtml({
-                    items: MediaController.playlist(),
-                    smallIcon: true
-                });
-
-                playlistNeedsRefresh = false;
-            }
+            playlistNeedsRefresh = false;
 
             var deps = [];
 
-            if (playlistOpen) {
-                deps.push('paper-icon-item');
-                deps.push('paper-item-body');
-            }
-
             require(deps, function () {
 
                 var itemsContainer = context.querySelector('.playlist');
 
                 itemsContainer.innerHTML = html;
 
-                if (playlistOpen) {
+                var index = MediaController.currentPlaylistIndex();
 
-                    var index = MediaController.currentPlaylistIndex();
+                if (index != -1) {
 
-                    if (index != -1) {
+                    var item = itemsContainer.querySelectorAll('.listItem')[index];
+                    if (item) {
+                        var img = item.querySelector('.listItemImage');
 
-                        var item = itemsContainer.querySelectorAll('.listItem')[index];
-                        if (item) {
-                            var img = item.querySelector('.listviewImage');
-
-                            img.classList.remove('lazy');
-                            img.classList.add('playlistIndexIndicatorImage');
-                        }
+                        img.classList.remove('lazy');
+                        img.classList.add('playlistIndexIndicatorImage');
                     }
                 }
 
@@ -456,10 +448,6 @@
             });
         }
 
-        function isPlaylistOpen(context) {
-            return context.querySelector('paper-tabs').selected == 2;
-        }
-
         function onStateChanged(e, state) {
 
             if (e.type == 'positionchange') {
@@ -483,11 +471,7 @@
 
             onStateChanged.call(player, e, state);
 
-            if (isPlaylistOpen(dlg)) {
-                loadPlaylist(dlg);
-            } else {
-                playlistNeedsRefresh = true;
-            }
+            loadPlaylist(dlg);
         }
 
         function onPlaybackStopped(e, state) {
@@ -498,11 +482,7 @@
 
             onStateChanged.call(player, e, {});
 
-            if (isPlaylistOpen(dlg)) {
-                loadPlaylist(dlg);
-            } else {
-                playlistNeedsRefresh = true;
-            }
+            loadPlaylist(dlg);
         }
 
         function releaseCurrentPlayer() {
@@ -555,13 +535,13 @@
 
             if (info.isLocalPlayer) {
 
-                btnCast.icon = 'cast';
+                btnCast.querySelector('i').innerHTML = 'cast';
                 btnCast.classList.remove('btnActiveCast');
                 context.querySelector('.nowPlayingSelectedPlayer').innerHTML = '';
 
             } else {
 
-                btnCast.icon = 'cast-connected';
+                btnCast.querySelector('i').innerHTML = 'cast-connected';
                 btnCast.classList.add('btnActiveCast');
                 context.querySelector('.nowPlayingSelectedPlayer').innerHTML = info.deviceName || info.name;
             }
@@ -580,59 +560,26 @@
             return elem;
         }
 
-        function onContextClick(e) {
+        function onBtnCommandClick() {
+            if (currentPlayer) {
 
-            var lnkPlayFromIndex = parentWithClass(e.target, 'lnkPlayFromIndex');
-            if (lnkPlayFromIndex != null) {
-                var index = parseInt(lnkPlayFromIndex.getAttribute('data-index'));
+                if (this.classList.contains('repeatToggleButton')) {
+                    toggleRepeat(currentPlayer);
+                } else {
+                    MediaController.sendCommand({
+                        Name: this.getAttribute('data-command')
 
-                MediaController.currentPlaylistIndex(index);
-                loadPlaylist(context);
-
-                e.preventDefault();
-                e.stopPropagation();
-                return false;
-            }
-            var lnkRemoveFromPlaylist = parentWithClass(e.target, 'lnkRemoveFromPlaylist');
-            if (lnkRemoveFromPlaylist != null) {
-                var index = parseInt(lnkRemoveFromPlaylist.getAttribute('data-index'));
-
-                MediaController.removeFromPlaylist(index);
-                loadPlaylist(context);
-
-                e.preventDefault();
-                e.stopPropagation();
-                return false;
-            }
-
-            var mediaItem = parentWithClass(e.target, 'mediaItem');
-            if (mediaItem != null) {
-                var info = LibraryBrowser.getListItemInfo(mediaItem);
-
-                MediaController.currentPlaylistIndex(info.index);
-
-                e.preventDefault();
-                e.stopPropagation();
-                return false;
+                    }, currentPlayer);
+                }
             }
         }
 
         function bindEvents(context) {
 
-            $('.btnCommand', context).on('click', function () {
-
-                if (currentPlayer) {
-
-                    if (this.classList.contains('repeatToggleButton')) {
-                        toggleRepeat(currentPlayer);
-                    } else {
-                        MediaController.sendCommand({
-                            Name: this.getAttribute('data-command')
-
-                        }, currentPlayer);
-                    }
-                }
-            });
+            var btnCommand = context.querySelectorAll('.btnCommand');
+            for (var i = 0, length = btnCommand.length; i < length; i++) {
+                btnCommand[i].addEventListener('click', onBtnCommandClick);
+            }
 
             context.querySelector('.btnToggleFullscreen').addEventListener('click', function (e) {
 
@@ -718,23 +665,20 @@
                 }
             });
 
-            context.querySelector('.nowPlayingPositionSlider', context)._setPinValue = function (value) {
+            context.querySelector('.nowPlayingPositionSlider', context).getBubbleText = function (value) {
 
                 var state = lastPlayerState;
 
                 if (!state || !state.NowPlayingItem || !state.NowPlayingItem.RunTimeTicks) {
-                    this.pinValue = '--:--';
-                    return;
+                    return '--:--';
                 }
 
                 var ticks = state.NowPlayingItem.RunTimeTicks;
                 ticks /= 100;
                 ticks *= value;
 
-                this.pinValue = Dashboard.getDisplayTime(ticks);
+                return datetime.getDisplayRunningTime(ticks);
             };
-
-            context.addEventListener('click', onContextClick);
         }
 
         function onPlayerChange() {
@@ -752,14 +696,16 @@
                 Name: 'DisplayMessage',
                 Arguments: {
 
-                    Header: $('#txtMessageTitle', form).val(),
-                    Text: $('#txtMessageText', form).val()
+                    Header: form.querySelector('#txtMessageTitle').value,
+                    Text: form.querySelector('#txtMessageText', form).value
                 }
 
             }, currentPlayer);
 
-            $('input', form).val('');
-            Dashboard.alert('Message sent.');
+            form.querySelector('input').value = '';
+            require(['toast'], function (toast) {
+                toast('Message sent.');
+            });
 
             e.preventDefault();
             e.stopPropagation();
@@ -774,40 +720,24 @@
                 Name: 'SendString',
                 Arguments: {
 
-                    String: $('#txtTypeText', form).val()
+                    String: form.querySelector('#txtTypeText', form).value
                 }
 
             }, currentPlayer);
 
-            $('input', form).val('');
-            Dashboard.alert('Text sent.');
+            form.querySelector('input').value = '';
+            require(['toast'], function (toast) {
+                toast('Text sent.');
+            });
 
             e.preventDefault();
             e.stopPropagation();
             return false;
         }
 
-        function showTab(index) {
+        function init(ownerView, context) {
 
-            var all = dlg.querySelectorAll('.nowPlayingPageTab');
-
-            index = (index || 0).toString();
-
-            for (var i = 0, length = all.length; i < length; i++) {
-
-                var tab = all[i];
-
-                if (tab.getAttribute('data-tab') == index) {
-                    tab.classList.remove('hide');
-                } else {
-                    tab.classList.add('hide');
-                }
-            }
-        }
-
-        function init(context) {
-
-            Dashboard.importCss('css/nowplaying.css');
+            require(['css!css/nowplaying.css']);
             bindEvents(context);
 
             context.querySelector('.sendMessageForm').addEventListener('submit', onMessageSubmit);
@@ -825,45 +755,24 @@
             //    showSlideshowMenu(context);
             //});
 
-            var tabs = context.querySelector('paper-tabs');
+            var mdlTabs = context.querySelector('.libraryViewNav');
 
             if (AppInfo.enableNowPlayingPageBottomTabs) {
-                tabs.classList.remove('hide');
-                context.querySelector('.libraryViewNav').classList.add('hide');
+                context.querySelector('.libraryViewNav').classList.add('bottom');
             } else {
-                tabs.classList.add('hide');
-                context.querySelector('.libraryViewNav').classList.remove('hide');
+                context.querySelector('.libraryViewNav').classList.remove('bottom');
             }
 
-            tabs.noSlide = true;
+            libraryBrowser.configurePaperLibraryTabs(ownerView, mdlTabs, ownerView.querySelectorAll('.pageTabContent'));
 
-            tabs.addEventListener('iron-select', function (e) {
+            mdlTabs.addEventListener('tabchange', function (e) {
 
-                var btn = context.querySelector('.libraryViewNav a.ui-btn-active');
-
-                if (btn) {
-                    btn.classList.remove('ui-btn-active');
-                }
-
-                context.querySelector('.libraryViewNav a[data-index=\'' + e.target.selected + '\']').classList.add('ui-btn-active');
-
-                if (e.target.selected == 2 && playlistNeedsRefresh) {
+                if (e.detail.selectedTabIndex == 2 && playlistNeedsRefresh) {
                     loadPlaylist(context);
                 }
-
-                showTab(e.target.selected);
-            });
-
-            $(context.querySelectorAll('.libraryViewNav a')).on('click', function () {
-                var newSelected = this.getAttribute('data-index');
-
-                tabs.selected = newSelected;
             });
 
             Events.on(MediaController, 'playerchange', onPlayerChange);
-
-            $(context.querySelector('.itemsContainer')).createCardMenus();
-
         }
 
         function onDialogClosed(e) {
@@ -881,25 +790,10 @@
 
             bindToPlayer(context, MediaController.getCurrentPlayer());
 
-            var selected = tab == '#playlist' ? 2 : 0;
-
-            var delay = browser.animate ? 0 : 1000;
-
-            // hack alert. doing this because the neon elements don't seem to be initialized yet
-            setTimeout(function () {
-
-                if (AppInfo.enableNowPlayingPageBottomTabs) {
-                    context.querySelector('paper-tabs').selected = selected;
-                } else {
-
-                    showTab(selected);
-                }
-            }, delay);
-
             updateCastIcon(context);
         }
 
-        self.init = function (context) {
+        self.init = function (ownerView, context) {
 
             dlg = context;
 
@@ -908,7 +802,7 @@
                 context.querySelector('.topRightContainer').style.position = 'relative';
             }
 
-            init(dlg);
+            init(ownerView, dlg);
         };
 
         self.onShow = function () {
