@@ -1,4 +1,4 @@
-﻿define([], function () {
+﻿define(['listView', 'cardBuilder', 'emby-itemscontainer'], function (listView, cardBuilder) {
 
     function renderItems(page, item) {
 
@@ -82,7 +82,7 @@
             html += '<a href="#" class="clearLink hide" style="margin-left:1em;vertical-align:middle;"><button is="emby-button" type="button" class="raised more mini noIcon">' + Globalize.translate('ButtonMore') + '</button></a>';
             html += '</div>';
 
-            html += '<div class="itemsContainer">';
+            html += '<div is="emby-itemscontainer" class="itemsContainer">';
             html += '</div>';
 
             html += '</div>';
@@ -109,7 +109,7 @@
                     ArtistIds: "",
                     Limit: 10
                 }, {
-                    shape: "detailPagePortrait",
+                    shape: "portrait",
                     showTitle: true,
                     centerText: true,
                     overlayMoreButton: true
@@ -124,7 +124,7 @@
                     ArtistIds: "",
                     Limit: 10
                 }, {
-                    shape: "detailPagePortrait",
+                    shape: "portrait",
                     showTitle: true,
                     centerText: true,
                     overlayPlayButton: true
@@ -139,7 +139,7 @@
                     ArtistIds: "",
                     Limit: 10
                 }, {
-                    shape: "detailPagePortrait",
+                    shape: "portrait",
                     showTitle: true,
                     centerText: true,
                     overlayMoreButton: true
@@ -154,7 +154,7 @@
                     ArtistIds: "",
                     Limit: 10
                 }, {
-                    shape: "detailPagePortrait",
+                    shape: "portrait",
                     showTitle: true,
                     centerText: true,
                     overlayPlayButton: true
@@ -169,7 +169,7 @@
                     ArtistIds: "",
                     Limit: 10
                 }, {
-                    shape: "detailPagePortrait",
+                    shape: "portrait",
                     showTitle: true,
                     centerText: true,
                     overlayMoreButton: true
@@ -184,7 +184,7 @@
                     ArtistIds: "",
                     Limit: 8
                 }, {
-                    shape: "detailPageSquare",
+                    shape: "square",
                     playFromHere: true,
                     showTitle: true,
                     showParentTitle: true,
@@ -201,7 +201,7 @@
                     ArtistIds: "",
                     Limit: 6
                 }, {
-                    shape: "detailPage169",
+                    shape: "backdrop",
                     showTitle: true,
                     showParentTitle: true,
                     centerText: true,
@@ -218,7 +218,7 @@
                     Limit: 30
                 }, {
                     playFromHere: true,
-                    defaultAction: 'playallfromhere',
+                    action: 'playallfromhere',
                     smallIcon: true
                 });
                 break;
@@ -246,17 +246,20 @@
             }
 
             listOptions.items = result.Items;
+            var itemsContainer = element.querySelector('.itemsContainer');
 
             if (type == 'Audio') {
-                html = LibraryBrowser.getListViewHtml(listOptions);
+                html = listView.getListViewHtml(listOptions);
+                itemsContainer.classList.remove('vertical-wrap');
+                itemsContainer.classList.add('vertical-list');
             } else {
-                html = LibraryBrowser.getPosterViewHtml(listOptions);
+                html = cardBuilder.getCardsHtml(listOptions);
+                itemsContainer.classList.add('vertical-wrap');
+                itemsContainer.classList.remove('vertical-list');
             }
 
-            var itemsContainer = element.querySelector('.itemsContainer');
             itemsContainer.innerHTML = html;
 
-            LibraryBrowser.createCardMenus(itemsContainer);
             ImageLoader.lazyChildren(itemsContainer);
         });
     }
@@ -296,7 +299,7 @@
             SortOrder: "Ascending",
             IncludeItemTypes: "",
             Recursive: true,
-            Fields: "AudioInfo,SeriesInfo,ParentId,PrimaryImageAspectRatio,SyncInfo",
+            Fields: "AudioInfo,SeriesInfo,ParentId,PrimaryImageAspectRatio,BasicSyncInfo",
             Limit: LibraryBrowser.getDefaultPageSize(),
             StartIndex: 0,
             CollapseBoxSetItems: false
