@@ -76,7 +76,7 @@
                 html += '</paper-item-body>';
 
                 if (tuner.CanReset) {
-                    html += '<paper-icon-button icon="refresh" data-tunerid="' + tuner.Id + '" title="' + Globalize.translate('ButtonResetTuner') + '" class="btnResetTuner"></paper-icon-button>';
+                    html += '<button type="button" is="paper-icon-button-light" data-tunerid="' + tuner.Id + '" title="' + Globalize.translate('ButtonResetTuner') + '" class="btnResetTuner"><iron-icon icon="refresh"></iron-icon></button>';
                 }
 
                 html += '</paper-icon-item>';
@@ -214,7 +214,7 @@
                 html += '</a>';
                 html += '</paper-item-body>';
 
-                html += '<paper-icon-button icon="delete" data-id="' + device.Id + '" title="' + Globalize.translate('ButtonDelete') + '" class="btnDeleteDevice"></paper-icon-button>';
+                html += '<button type="button" is="paper-icon-button-light" class="btnDeleteDevice" data-id="' + device.Id + '" title="' + Globalize.translate('ButtonDelete') + '"><iron-icon icon="delete"></iron-icon></button>';
                 html += '</paper-icon-item>';
             }
 
@@ -263,6 +263,12 @@
 
             loadPage(page, liveTvInfo);
 
+        }, function () {
+
+            loadPage(page, {
+                Services: [],
+                IsEnabled: true
+            });
         });
     }
 
@@ -316,7 +322,7 @@
 
                 html += '</a>';
                 html += '</paper-item-body>';
-                html += '<paper-icon-button icon="delete" data-id="' + provider.Id + '" title="' + Globalize.translate('ButtonDelete') + '" class="btnDelete"></paper-icon-button>';
+                html += '<button type="button" is="paper-icon-button-light" class="btnOptions" data-id="' + provider.Id + '"><iron-icon icon="more-vert"></iron-icon></button>';
                 html += '</paper-icon-item>';
             }
 
@@ -325,11 +331,59 @@
 
         var elem = $('.providerList', page).html(html);
 
-        $('.btnDelete', elem).on('click', function () {
+        $('.btnOptions', elem).on('click', function () {
 
             var id = this.getAttribute('data-id');
 
-            deleteProvider(page, id);
+            showProviderOptions(page, id, this);
+        });
+    }
+
+    function showProviderOptions(page, providerId, button) {
+
+        var items = [];
+
+        items.push({
+            name: Globalize.translate('ButtonDelete'),
+            id: 'delete'
+        });
+
+        items.push({
+            name: Globalize.translate('MapChannels'),
+            id: 'map'
+        });
+
+        require(['actionsheet'], function (actionsheet) {
+
+            actionsheet.show({
+                items: items,
+                positionTo: button
+
+            }).then(function (id) {
+
+                switch (id) {
+
+                    case 'delete':
+                        deleteProvider(page, providerId);
+                        break;
+                    case 'map':
+                        mapChannels(page, providerId);
+                        break;
+                    default:
+                        break;
+                }
+            });
+
+        });
+    }
+
+    function mapChannels(page, providerId) {
+
+        require(['components/channelmapper/channelmapper'], function (channelmapper) {
+            new channelmapper({
+                serverId: ApiClient.serverInfo().Id,
+                providerId: providerId
+            }).show();
         });
     }
 
@@ -386,6 +440,8 @@
 
             case 'schedulesdirect':
                 return 'Schedules Direct';
+            case 'xmltv':
+                return 'Xml TV';
             case 'emby':
                 return 'Emby Guide';
             default:
@@ -399,6 +455,8 @@
 
         switch (providerId) {
 
+            case 'xmltv':
+                return 'livetvguideprovider.html?type=xmltv';
             case 'schedulesdirect':
                 return 'livetvguideprovider.html?type=schedulesdirect';
             case 'emby':
@@ -422,6 +480,11 @@
         //    id: 'emby'
         //});
 
+        menuItems.push({
+            name: 'Xml TV',
+            id: 'xmltv'
+        });
+
         menuItems.push({
             name: Globalize.translate('ButtonOther'),
             id: 'other'
@@ -491,6 +554,22 @@
         });
     }
 
+    function getTabs() {
+        return [
+        {
+            href: 'livetvstatus.html',
+            name: Globalize.translate('TabDevices')
+        },
+         {
+             href: 'livetvsettings.html',
+             name: Globalize.translate('TabSettings')
+         },
+         {
+             href: 'appservices.html?context=livetv',
+             name: Globalize.translate('TabServices')
+         }];
+    }
+
     $(document).on('pageinit', "#liveTvStatusPage", function () {
 
         var page = this;
@@ -510,6 +589,7 @@
 
     }).on('pageshow', "#liveTvStatusPage", function () {
 
+        LibraryMenu.setTabs('livetvadmin', 0, getTabs);
         var page = this;
 
         reload(page);
