@@ -1,4 +1,4 @@
-﻿define(['jQuery'], function ($) {
+﻿define(['jQuery', 'paper-icon-button-light', 'cardStyle'], function ($) {
 
     function cancelJob(page, id) {
 
@@ -60,7 +60,7 @@
 
         var html = '';
 
-        html += "<div class='card squareCard' data-id='" + job.Id + "' data-status='" + job.Status + "'>";
+        html += "<div class='card squareCard scalableCard' data-id='" + job.Id + "' data-status='" + job.Status + "'>";
 
         html += '<div class="' + cardBoxCssClass + '">';
         html += '<div class="cardScalable">';
@@ -133,7 +133,7 @@
         }
 
         html += '<div class="cardText" style="text-align:right; float:right;padding:0;">';
-        html += '<paper-icon-button icon="' + AppInfo.moreIcon + '" class="btnJobMenu"></paper-icon-button>';
+        html += '<button type="button" is="paper-icon-button-light" class="btnJobMenu autoSize"><i class="md-icon">' + AppInfo.moreIcon.replace('-', '_') + '</i></button>';
         html += "</div>";
 
         for (var i = 0, length = textLines.length; i < length; i++) {
@@ -179,6 +179,8 @@
             showTargetName = !hasLocalSync();
         }
 
+        var hasOpenSection = false;
+
         for (var i = 0, length = jobs.length; i < length; i++) {
 
             var job = jobs[i];
@@ -188,9 +190,11 @@
                 if (targetName != lastTargetName) {
 
                     if (lastTargetName) {
+                        html += '</div>';
                         html += '<br/>';
                         html += '<br/>';
                         html += '<br/>';
+                        hasOpenSection = false;
                     }
 
                     lastTargetName = targetName;
@@ -200,12 +204,18 @@
                     html += '<div>' + targetName + '</div>';
 
                     html += '</div>';
+                    html += '<div class="itemsContainer vertical-wrap">';
+                    hasOpenSection = true;
                 }
             }
 
             html += getSyncJobHtml(page, job, cardBoxCssClass, syncJobPage);
         }
 
+        if (hasOpenSection) {
+            html += '</div>';
+        }
+
         var elem = $('.syncActivity', page).html(html).lazyChildren();
 
         $('.btnJobMenu', elem).on('click', function () {
@@ -277,14 +287,12 @@
         if (status == 'Cancelled') {
             menuItems.push({
                 name: Globalize.translate('ButtonDelete'),
-                id: 'delete',
-                ironIcon: 'delete'
+                id: 'delete'
             });
         } else {
             menuItems.push({
                 name: Globalize.translate('ButtonCancelSyncJob'),
-                id: 'cancel',
-                ironIcon: 'delete'
+                id: 'cancel'
             });
         }
 
@@ -392,6 +400,10 @@
              href: 'devicesupload.html',
              name: Globalize.translate('TabCameraUpload')
          },
+        {
+            href: 'appservices.html?context=sync',
+            name: Globalize.translate('TabServices')
+        },
          {
              href: 'syncsettings.html',
              name: Globalize.translate('TabSettings')
